\name{TileReadSignal}
\alias{TileReadSignal}
\title{TileReadSignal}
\usage{TileReadSignal(signal.filename, bpmap.filename, minhits=8000,
    group="Hs", gc=TRUE, matchscore=FALSE, verbose=FALSE)}
\description{Reads tiling array data from an Affymetrix BPMAP file and a TAS-created
signal.txt file.}
\details{Reads tiling array data in terms of an Affymetrix BPMAP (binary probe
mapping) file and the human-readable signal.txt files that are created by the
Tiling Array Software (TAS) from Affymetrix. The signal files comprise
information on the genomic map entry (e.g. chromosome name), probe center
positions and probe intensities. The intensities are assumed to be in
\code{log2} scale. The method generates a \code{data.frame} comprising all
required data on probes that are necessary for the subsequent shuffling
analysis.}
\value{Returns a \code{data.frame} containing information on all probes,
i.e., the full name of the reference sequence (organism abbreviation
and chromosome name), the chromosome name, the probe center position,
the length of the probe sequence, the GC content of the probe
sequence, the match score (if \code{matchscore} is enabled), and
the probe score.}
\note{This method is deprecated since it was specifically designed
for the Affymetrix Human tiling array 1.0R platform and the files
created by TAS. Please consider using \code{\link{TileReadCel}} or
\code{\link{TileReadCustom}} instead.}
\arguments{\item{signal.filename}{Filename of human-readable signal.txt file
(as a \code{character}) created by the Tiling Array Software (TAS).}
\item{bpmap.filename}{Filename of Affymetrix binary probe mapping (BPMAP)
file (as a \code{character}), which is a binary file containing
information on the location of each probe in the reference sequence.
Moreover, it stores the probe sequences that are necessary to
calculate the GC content.}
\item{minhits}{Minimal number of hits in BPMAP entry to be considered for
the further analysis. Due to historical reasons there are several
entries in the BPMAP file with only around thousand probes assigned
that might overlap with the larger entries or with entries on other
tiling arrays. In case of Affy tiling array 1.0R, a value of 8000
is recommended.}
\item{group}{A group name as the organism abbreviation in order to consider
only these entries in the BPMAP file and hence disregard entries such
as TIGR, Affymetrix, or bacterial controls.}
\item{gc}{Indicates whether GC content of probe sequences will be
calculated. It is defined as fraction of both Gs and Cs in the
probe sequence.}
\item{matchscore}{Indicates whether match score will be read. The match
score is defined as number of perfect matches of the probe sequence
per megabase of the genomic sequence. This information needs to be
set accordingly in the BPMAP file. Otherwise, all probes contain only
the default value.}
\item{verbose}{Indicates whether information on progress are printed.}}
